Introduction
============

This part of the documentation describes the public DebOps API which is used
internally by the project but can also be used by third parties.

API URL: https://api.debops.org/

Example usages
--------------

* https://github.com/debops/debops.github.io
* https://github.com/debops/docs

..
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 End:
